@@ -3,18 +3,11 @@
 
 import argparse
 import sys
-import os
-import multiprocessing
-
 from deeptools.parserCommon import writableFile, numberOfProcessors
-try:  # keep python 3.7 support.
-    from importlib.metadata import version
-except ModuleNotFoundError:
-    from importlib_metadata import version
 from deeptools import parserCommon
 from deeptools import heatmapper
 import deeptools.computeMatrixOperations as cmo
-import deeptools.deepBlue as db
+from importlib.metadata import version
 
 
 def parse_arguments(args=None):
@@ -47,17 +40,16 @@ $ computeMatrix scale-regions --help
         dest='command',
         metavar='')
 
-    dbParser = parserCommon.deepBlueOptionalArgs()
-
     # scale-regions mode options
     subparsers.add_parser(
         'scale-regions',
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-        parents=[computeMatrixRequiredArgs(),
-                 computeMatrixOutputArgs(),
-                 computeMatrixOptArgs(case='scale-regions'),
-                 parserCommon.gtf_options(),
-                 dbParser],
+        parents=[
+            computeMatrixRequiredArgs(),
+            computeMatrixOutputArgs(),
+            computeMatrixOptArgs(case='scale-regions'),
+            parserCommon.gtf_options()
+        ],
         help="In the scale-regions mode, all regions in the BED file are "
         "stretched or shrunken to the length (in bases) indicated by the user.",
         usage='An example usage is:\n  computeMatrix scale-regions -S '
@@ -70,8 +62,8 @@ $ computeMatrix scale-regions --help
         parents=[computeMatrixRequiredArgs(),
                  computeMatrixOutputArgs(),
                  computeMatrixOptArgs(case='reference-point'),
-                 parserCommon.gtf_options(),
-                 dbParser],
+                 parserCommon.gtf_options()
+                 ],
         help="Reference-point refers to a position within a BED region "
         "(e.g., the starting point). In this mode, only those genomic"
         "positions before (upstream) and/or after (downstream) of the "
@@ -402,28 +394,6 @@ def main(args=None):
 
     hm = heatmapper.heatmapper()
 
-    # Preload deepBlue files, which need to then be deleted
-    deepBlueFiles = []
-    for idx, fname in enumerate(args.scoreFileName):
-        if db.isDeepBlue(fname):
-            deepBlueFiles.append([fname, idx])
-    if len(deepBlueFiles) > 0:
-        sys.stderr.write("Preloading the following deepBlue files: {}\n".format(",".join([x[0] for x in deepBlueFiles])))
-        regs = db.makeRegions(args.regionsFileName, args)
-        for x in deepBlueFiles:
-            x.extend([args, regs])
-        if len(deepBlueFiles) > 1 and args.numberOfProcessors > 1:
-            pool = multiprocessing.Pool(args.numberOfProcessors)
-            res = pool.map_async(db.preloadWrapper, deepBlueFiles).get(9999999)
-        else:
-            res = list(map(db.preloadWrapper, deepBlueFiles))
-
-        # substitute the file names with the temp files
-        for (ftuple, r) in zip(deepBlueFiles, res):
-            args.scoreFileName[ftuple[1]] = r
-        deepBlueFiles = [[x[0], x[1]] for x in deepBlueFiles]
-        del regs
-
     scores_file_list = args.scoreFileName
     hm.computeMatrix(scores_file_list, args.regionsFileName, parameters, blackListFileName=args.blackListFileName, verbose=args.verbose, allArgs=args)
     if args.sortRegions not in ['no', 'keep']:
@@ -449,11 +419,3 @@ def main(args=None):
 
     if args.outFileSortedRegions:
         hm.save_BED(args.outFileSortedRegions)
-
-    # Clean up temporary bigWig files, if applicable
-    if not args.deepBlueKeepTemp:
-        for k, v in deepBlueFiles:
-            os.remove(args.scoreFileName[v])
-    else:
-        for k, v in deepBlueFiles:
-            print("{} is stored in {}".format(k, args.scoreFileName[v]))
